#version 330

// Position of the fragment in camera space:
in vec3 position_from_vs;

// Normal in camera space:
in vec3 normal_from_vs;

// Texture coordinate:
in vec2 texCoord_from_vs;

// Material color texture:
uniform bool useMaterialColorTexture;
uniform sampler2D materialColorTexture;

// Material parameters:
uniform vec3 materialColor;
uniform float materialShininess;

// The position in camera space should be written into this variable:
layout (location = 0) out vec3 gBufferPosition;

// The normal in camera space should be written into this variable:
layout (location = 1) out vec3 gBufferNormal;

//The material color and shininess should be written into this variable:
layout (location = 2) out vec4 gBufferMaterial;

void main() {
    // Define k-parameter (this can be used for kA and KS too!):
    vec3 k = materialColor;

    // If a color texture is available, apply it:
    if(useMaterialColorTexture){
        k *= texture2D(materialColorTexture, texCoord_from_vs).rgb;
    }

    // TODO:
    // (2a) Write the attributes which are needed for lighting
    // into the gBuffers.
    //
    // Note that the textures where the gBufferPosition and
    // gBufferNormal is written to store each value in a float
    // variable (can contain arbitrary floating point numbers).
    //
    // Compared to that, the gBufferMaterial variable is written
    // to a texture which stores only 8-bit integers for
    // performance reasons, which is enough for the rgb colors.
    // You can use it's alpha channel (a) to store the shininess,
    // but note that the values are clamped in the range [0, 1]
    // in this case. In our application, we use a range of
    // shininess from 0 to 200, so you have to scale that variable
    // when writing it out to the alpha channel so that it fits in
    // a value from 0 to 1 and undo that scaling, when you read
    // the texture in the deferredLightingPass2 shader.

    gBufferPosition = vec3(0.0, 0.0, 0.0); // <- Position
    gBufferNormal = vec3(0.0, 0.0, 0.0); // <- Normal
    gBufferMaterial = vec4(0.0, 0.0, 1.0, 0.0); // <- Material Color + Shininess
}
