#include "StaticMeshActor.h"

#include "Barycentric.h"

StaticMeshActor::StaticMeshActor(Mesh mesh, Mat4f modelMatrix, Vec4f diffuseColor, float shininess)
    : mesh(mesh)
    , modelMatrix(modelMatrix)
    , diffuseColor(diffuseColor)
    , shininess(shininess)
{}

StaticMeshActor::StaticMeshActor(Mesh mesh, Texture2D texture, Mat4f modelMatrix, Vec4f diffuseColor, float shininess)
    : mesh(mesh)
    , texture(texture)
    , modelMatrix(modelMatrix)
    , diffuseColor(diffuseColor)
    , shininess(shininess)
{}

void StaticMeshActor::render(Mat4f view, Mat4f projection, Shader shader){
    // Bind the texture:
    texture.bind(0);
    shader.setUniform("materialColorTexture", 0);

    // Only use mesh texture if it's not a dummy:
    shader.setUniform("useMaterialColorTexture", !texture.isDummy());

    // Color of the mesh:
    shader.setUniform("materialColor", diffuseColor, 3);

    // Shininess of the mesh:
    shader.setUniform("materialShininess", shininess);

    // Assume that our world mesh is already correctly transformed in the world
    // so we upload just the identity matrix:
    shader.setUniform("model", modelMatrix);

    // Upload our view matrix, which performs the transformation to view the
    // world from the 'perspective' of something, e.g. a camera or a pawn:
    shader.setUniform("view", view);

    // Upload the projection matrix (used in vertex shader):
    shader.setUniform("projection", projection);

    // Draw our triangle:
    mesh.render();
}

Mat4f StaticMeshActor::getModelMatrix(){
    return modelMatrix;
}
